==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/resource/api/type/gwt/serder/ResourceTypeGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.type.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ResourceTypeGwtSerDer implements GwtSerDer<net.bluemind.resource.api.type.ResourceType> {

	public ResourceTypeGwtSerDer( ) {
	}

	@Override
	public net.bluemind.resource.api.type.ResourceType deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.resource.api.type.ResourceType ret = new net.bluemind.resource.api.type.ResourceType();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.resource.api.type.ResourceType ret, JSONObject json) {

		JSONValue identifierJSON = json.get("identifier");
		ret.identifier =  GwtSerDerUtils.STRING.deserialize(identifierJSON);
		JSONValue labelJSON = json.get("label");
		ret.label =  GwtSerDerUtils.STRING.deserialize(labelJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.resource.api.type.ResourceType o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.resource.api.type.ResourceType o, JSONObject ret) {

		ret.put("identifier",  GwtSerDerUtils.STRING.serialize( o.identifier ));
		ret.put("label",  GwtSerDerUtils.STRING.serialize( o.label ));
	}
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/resource/api/type/gwt/serder/ResourceTypeGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.type.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class ResourceTypeGwtSerDer implements GwtSerDer<net.bluemind.resource.api.type.ResourceType> {

	public ResourceTypeGwtSerDer( ) {
	}

	@Override
	public net.bluemind.resource.api.type.ResourceType deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.resource.api.type.ResourceType ret = new net.bluemind.resource.api.type.ResourceType();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.resource.api.type.ResourceType ret, JSONObject json) {
		JSONValue identifierJSON = json.get("identifier");
		ret.identifier =  GwtSerDerUtils.STRING.deserialize(identifierJSON);
		JSONValue labelJSON = json.get("label");
		ret.label =  GwtSerDerUtils.STRING.deserialize(labelJSON);
	}

	public void deserializeTo(net.bluemind.resource.api.type.ResourceType ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("identifier")) {
			JSONValue identifierJSON = json.get("identifier");
			ret.identifier =  GwtSerDerUtils.STRING.deserialize(identifierJSON);
		}
		if (!childPropertiesToIgnore.contains("label")) {
			JSONValue labelJSON = json.get("label");
			ret.label =  GwtSerDerUtils.STRING.deserialize(labelJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.resource.api.type.ResourceType o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.resource.api.type.ResourceType o, JSONObject ret) {

		ret.put("identifier",  GwtSerDerUtils.STRING.serialize( o.identifier ));
		ret.put("label",  GwtSerDerUtils.STRING.serialize( o.label ));
	}

	public void serializeTo(net.bluemind.resource.api.type.ResourceType o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("identifier")) {
			ret.put("identifier",  GwtSerDerUtils.STRING.serialize( o.identifier ));
		}
		if (!childPropertiesToIgnore.contains("label")) {
			ret.put("label",  GwtSerDerUtils.STRING.serialize( o.label ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
